#!/bin/bash
#
# Script to install the native parts of the arm gcc distribution for Linux
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

SRC_NAME_ORIG=arm-gcc
SRC_NAME=arm-gcc-temp
INSTALL_LOC=_install/${compiler_loc}

# First cleanup everything
log_exec rm -rf $SRC_NAME _install/*
log_exec mkdir -p $SRC_NAME
log_exec cp -rf $SRC_NAME_ORIG/* $SRC_NAME
log_exec mkdir -p $INSTALL_LOC/usr

# Install the cross-gcc script and symbolic links
log_exec mkdir -p $INSTALL_LOC/bin
log_exec cp cross-gcc $INSTALL_LOC/bin
log_exec chmod a+x $INSTALL_LOC/bin/cross-gcc

log "Then create link to cross-gcc from ${arch_compiler_prefix}- tools"
for tool in $SRC_NAME/bin/${compiler_prefix}-*; do
	if [ -r $tool ]; then
		tool_name=${tool##*/${compiler_prefix}-}

		# Internel pkg-config must not be used, it does search in internal sysroot		
		if [[ $tool_name == *"pkg-config"* ]]; then	
			continue
		fi

		log_exec ln -nfs cross-gcc $INSTALL_LOC/bin/${arch_compiler_prefix}-${tool_name}
	fi
done

# And install the cross compiler itself

# It would be nice to delete all files that are installed as part of the C library package 
# (target components already installed in the target sysroot); however, when compiling 
# some components, like the linux kernel, we need to use directly the cross-compiler itself
# without going through our wrapper which is really meant only for user-mode programs. 
# However, for programs like the kernel and bootloaders, you can't use any C libraries
# except the static libraries bundled with the compiler, so we nonetheless remove them.
#
# That's why we have to comment-out part of the cleanup code below to allow the compiler
# to be used for bare-metal, non-hosted, program development
#

log "Cleanup unused, target user-level components" 
# Glibc components
log_exec rm -rf $SRC_NAME/$compiler_prefix/libc
# Note that the content of $SRC_NAME/$compiler_prefix/lib is included in $SRC_NAME/$compiler_prefix/libc/lib
log_exec rm -rf $SRC_NAME/$compiler_prefix/lib

# Target executable files
log_exec rm -rf $SRC_NAME/bin/gdbserver
 
if false; then	
	# GCC include files
	log_exec rm -rf $SRC_NAME/$compiler_prefix/include/c++/${recipe_version}
	log_exec rm -rf $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/include 
	log_exec rm -rf $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/include-fixed
	
	# Save native GCC components
	log_exec mkdir _install/tmp
	log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/finclude _install/tmp
	log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/install-tools _install/tmp
	log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/plugin _install/tmp
	
	# GCC-provided library files
	log_exec rm -rf $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}
	
	# Restore native components
	log_exec mkdir -p $SRC_NAME/lib/gcc/$compiler_prefix
	log_exec mv _install/tmp $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}
fi

# Then install all remaining (native) components in the native sysroot

log "Install the bare-metal compiler itself"
log_exec mv $SRC_NAME/* $INSTALL_LOC/usr

log "And clean up the work environment"
log_exec rm -rf $SRC_NAME
