#!/bin/bash
#
# Script to install the target C library elements of the arm gcc distribution for Linux
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

SRC_NAME_ORIG=arm-gcc
SRC_NAME=arm-gcc-temp

# First cleanup everything
log_exec rm -rf $SRC_NAME _install/*
log_exec mkdir -p $SRC_NAME
log_exec cp -rf $SRC_NAME_ORIG/* $SRC_NAME
log_exec mkdir -p _install

# Copy GLIBC files
log_exec mv $SRC_NAME/$compiler_prefix/libc/* _install
log_exec rsync -av $SRC_NAME/$compiler_prefix/lib/* _install/lib
# Note that the content of $SRC_NAME/$compiler_prefix/lib is included in $SRC_NAME/$compiler_prefix/libc/lib

# Copy target executable files
log_exec mkdir -p _install/usr/bin
log_exec mv $SRC_NAME/$compiler_prefix/debug-root/usr/bin/gdbserver _install/usr/bin

# Copy GCC include files
log_exec mkdir -p _install/usr/include
log_exec mv $SRC_NAME/$compiler_prefix/include/c++/${recipe_version} _install/usr/include/c++
log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/include _install/usr/include/gcc
log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/include-fixed _install/usr/include/gcc/fixed

# Consolidate includes in /usr/include for kernel compilation
for include in $(cd _install/usr/include/gcc; find . -type f); do
	include="${include#./}"
	subdir=$(dirname $include)
	if [[ " $subdir" =~ " fixed" ]]; then continue; fi
	if [ ! -r "_install/usr/include/$include" ]; then
		if [ "$subdir" != "." -a ! -d "_install/usr/include/$subdir" ]; then
			log_exec mkdir -p "_install/usr/include/$subdir"
		fi
		log_exec mv "_install/usr/include/gcc/$include" "_install/usr/include/$subdir"
	elif cmp -s "_install/usr/include/gcc/$include" "_install/usr/include/$include"; then
		log_exec rm -f "_install/usr/include/gcc/$include"
	fi
done
for subdir in $(cd _install/usr/include/gcc; find . -type d); do
	if [ "$subdir" = "." ]; then continue; fi
	if [ -z "$(find "_install/usr/include/gcc/$subdir" -type f)" ]; then
		log_exec rm -rf "_install/usr/include/gcc/$subdir"
	fi
done

# Remove native GCC components
log_exec rm -rf $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/finclude
log_exec rm -rf $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/install-tools
log_exec rm -rf $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/plugin

# Copy GCC-provided library files
log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version}/*.o _install/usr/lib
log_exec mv $SRC_NAME/lib/gcc/$compiler_prefix/${recipe_version} _install/usr/lib/gcc

log_exec rm -rf $SRC_NAME
