#!/bin/bash
# Script to fetch package sources

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

targetDir=$DOWNLOAD_LOC
srcUrl=$SRC_LOC
srcSha256=$SRC_SHA256
srcFilename=${srcUrl##*/}
srcFile="$targetDir/$srcFilename"

do_buildstep_prepend

check_downloaded_file() {
	local srcFile="$1"
	local cksumerror=${2:-false}
	if [ ! -r "$srcFile" ]; then
		return 1
	fi
	case $srcUrl in
		http://* | https://* | ftp://*)
			computed_sha256=$(sha256sum "$srcFile")
			computed_sha256=${computed_sha256%% *}
			if [ -n "$srcSha256" ]; then
				if [ "$srcSha256" != "$computed_sha256" ]; then
					if cksumerror; then
						error "Sha256 checksum for '$srcFile' is wrong: expected '$srcSha256', found '$computed_sha256'"
						exit 1
					else
						warning "Found '$srcFile' but sha256 checksum is wrong: expected '$srcSha256', found '$computed_sha256'"
						return 1
					fi
				fi
			else
				warning "No sha256 checksum provided for '$srcUrl'; think at adding one for security"
				warning "Sha256 checksum for '$srcUrl' should be '$computed_sha256'"
			fi
			;;
	esac
	return 0
}

if check_downloaded_file "$srcFile"; then
	log "'$srcFilename' has been found in '$targetDir'"
else
	case $srcUrl in
		http://* | https://* | ftp://*)
			log "Downloading $srcUrl ... into $targetDir"
			rm -f "$srcFile" # Just in case the file exist but is not readable
			wget -nv -nc -P "$targetDir" "$srcUrl"
			check_downloaded_file "$srcFile" true
			;;
		*:*)
			error "Unsupported scheme: '${srcUrl%%:*}:'"
			exit 1
			;;
		*)
			if [ "$srcUrl" = "empty" ]; then
				srcDir="/tmp/fetch.$$"
				srcFilename="$srcUrl"
				srcUrl="$srcDir/$srcFilename"
				mkdir -p "$srcUrl"
			fi
			if [ -d "$srcUrl" ]; then
				if [ "$PACKAGE_VERSION" != "none" ]; then
					srcFile=${srcFile%-$PACKAGE_VERSION}-$PACKAGE_VERSION
				fi
				if [ -r "$srcFile.tar.bz2" ]; then
					echo "'${srcFile##*/}.tar.bz2' has been found in '$targetDir'"
				else
					srcDir=${srcUrl%/*}
					echo "Packing '$srcUrl' in '$srcFile.tar.bz2'"
					tar cjf "$srcFile.tar.bz2" -C "$srcDir" "$srcFilename"
				fi
			else
				echo "Copying '$srcUrl' in '$targetDir'"
				cp "$srcUrl" "$targetDir"
			fi
			;;
	esac
fi

do_buildstep_append

